Exception: Helo::WebhookSignatures::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/helo/webhook_signatures.rb

Overview

Base class for every rejection reason, so callers that do not care why a webhook was rejected can rescue this one class.