Exception: Helo::WebhookSignatures::SignatureMismatchError

Inherits:
Error
  • Object
show all
Defined in:
lib/helo/webhook_signatures.rb

Overview

The signature did not match the body, either because the body was tampered with or the signing key is wrong.