Exception: Helo::WebhookSignatures::TimestampSkewError
- Defined in:
- lib/helo/webhook_signatures.rb
Overview
The signature was correctly formed but its timestamp is too far from the current time, so it may be a replay.
The signature was correctly formed but its timestamp is too far from the current time, so it may be a replay.